@@ -13,7 +13,6 @@
 #include "linearalgebra.h"
 #include "loglik_POCov.h"
 #include "nelmin.h"
-#include "ListBuilder.h"
 // [[Rcpp::depends(RcppArmadillo,RcppProgress)]]
 
 // [[Rcpp::export]]
@@ -830,17 +829,18 @@ Rcpp::List fmodel3(const arma::mat& Outcome,
 
 
 
-	return ListBuilder()
-		.add("resid", resid_save)
-		.add("theta", theta_save)
-		.add("Omega", Omega_save)
-		.add("Sigma", Sig_save)
-		.add("delta", delta_save)
-		.add("Rho", Rho_save)
-		.add("R", Rtk_save)
-	    .add("pR", pRtk_save)
-		.add("delta_acceptance", delta_rates / static_cast<double>(ndiscard + nskip*nkeep))
-		.add("vRho_acceptance", vRho_rates / static_cast<double>(ndiscard + nskip*nkeep))
-	    .add("vR_acceptance", vR_rates / static_cast<double>(ndiscard + nskip*nkeep));
+	return Rcpp::List::create(
+			Rcpp::Named("resid") = resid_save,
+			Rcpp::Named("theta") = theta_save,
+			Rcpp::Named("Omega") = Omega_save,
+			Rcpp::Named("Sigma") = Sig_save,
+			Rcpp::Named("delta") = delta_save,
+			Rcpp::Named("Rho") = Rho_save,
+			Rcpp::Named("R") = Rtk_save,
+		    Rcpp::Named("pR") = pRtk_save,
+			Rcpp::Named("delta_acceptance") = delta_rates / static_cast<double>(ndiscard + nskip*nkeep),
+			Rcpp::Named("vRho_acceptance") = vRho_rates / static_cast<double>(ndiscard + nskip*nkeep),
+		    Rcpp::Named("vR_acceptance") = vR_rates / static_cast<double>(ndiscard + nskip*nkeep)
+		);
 }
 
